pub enum ParameterHeadingStyle {
Display,
Name,
Custom(Arc<dyn Fn(&ParameterInfo) -> String + Send + Sync + 'static>),
}Expand description
Controls how detailed parameter headings are rendered.
Variants
Display
Render the full clap display form, such as ``### `-c
Name
Render the clap argument id, such as ### config.
Custom(Arc<dyn Fn(&ParameterInfo) -> String + Send + Sync + 'static>)
Render the parameter heading with a callback.
If the callback returns an empty string, the heading is skipped.
Implementations