pub enum SummaryEntryStyle {
Default,
Custom(Arc<dyn Fn(&ParameterInfo) -> String + Send + Sync + 'static>),
}Expand description
Controls how parameter summary entries are rendered.
Variants
Default
Render the default linked summary entry.
Custom(Arc<dyn Fn(&ParameterInfo) -> String + Send + Sync + 'static>)
Render each summary entry with a callback.
The callback should return a complete Markdown list item. If it returns an empty string, the parameter is skipped from the summary.
Implementations
Sourceimpl SummaryEntryStyle
impl SummaryEntryStyle
Sourcepub fn custom(
formatter: impl Fn(&ParameterInfo) -> String + Send + Sync + 'static,
) -> Self
pub fn custom( formatter: impl Fn(&ParameterInfo) -> String + Send + Sync + 'static, ) -> Self
Create a custom summary entry callback.
Sourcepub fn render(
&self,
parameter: &ParameterInfo,
options: &SummaryOptions,
output: &mut String,
)
pub fn render( &self, parameter: &ParameterInfo, options: &SummaryOptions, output: &mut String, )
Render a summary entry for the given parameter.