pub enum SummaryValueStyle {
NamesOnly,
NamesAndValues,
}Expand description
Controls how parameter names are rendered in the summary.
Variants
NamesOnly
Render only parameter names, such as -c, --config.
NamesAndValues
Render parameter names and their values, such as -c <CONFIG>, --config <CONFIG>.