MarkdownOptions

Struct MarkdownOptions 

pub struct MarkdownOptions {
    pub include_hidden: bool,
    pub include_subcommands: bool,
    pub include_toc: bool,
    pub skip_parameter_details: bool,
    pub include_html_anchors: bool,
    pub include_usage: bool,
    pub command_heading: CommandHeadingStyle,
    pub summary: SummaryOptions,
    pub parameter_heading: ParameterHeadingStyle,
    pub parameter_content: ParameterContentStyle,
}
Rendering options for Markdown generation.

Fields

include_hidden: bool

Include hidden clap arguments and subcommands.

include_subcommands: bool

Include subcommands recursively.

include_toc: bool

Include a small parameter summary with links to each parameter.

skip_parameter_details: bool

Skip the detailed parameter sections.

include_html_anchors: bool

Include explicit HTML anchor id elements before parameters and subcommands.

include_usage: bool

Include a parameter usage line in detailed parameter content.

command_heading: CommandHeadingStyle

Controls how command headings are rendered.

summary: SummaryOptions

Controls how the parameter summary is rendered.

parameter_heading: ParameterHeadingStyle

Controls how each detailed parameter heading is rendered.

parameter_content: ParameterContentStyle

Controls how each detailed parameter body is rendered.