pub struct MarkdownOptions {
pub include_hidden: bool,
pub include_subcommands: bool,
pub include_toc: bool,
pub skip_parameter_details: bool,
pub include_html_anchors: bool,
pub include_usage: bool,
pub command_heading: CommandHeadingStyle,
pub summary: SummaryOptions,
pub parameter_heading: ParameterHeadingStyle,
pub parameter_content: ParameterContentStyle,
}Expand description
Rendering options for Markdown generation.
Fields
Include hidden clap arguments and subcommands.
include_subcommands: boolInclude subcommands recursively.
include_toc: boolInclude a small parameter summary with links to each parameter.
skip_parameter_details: boolSkip the detailed parameter sections.
include_html_anchors: boolInclude explicit HTML anchor id elements before parameters and subcommands.
include_usage: boolInclude a parameter usage line in detailed parameter content.
command_heading: CommandHeadingStyleControls how command headings are rendered.
summary: SummaryOptionsControls how the parameter summary is rendered.
parameter_heading: ParameterHeadingStyleControls how each detailed parameter heading is rendered.
parameter_content: ParameterContentStyleControls how each detailed parameter body is rendered.